<?php

/**
 * @file
 * Administrative forms and page callbacks for UC Paypoint.
 */

/**
 * Page callback to show the paypoint payment form and some explanation.
 */
function uc_paypoint_terminal($order) {
  $output = l(t('Return to order view screen.'), 'admin/store/orders/'. $order->order_id);

  $output .= '<p>'. t('Use this terminal to process paypoint payments.') .'</p>';

  $context = array(
    'revision' => 'formatted-original',
    'type' => 'order_total',
    'subject' => array(
      'order' => $order,
    ),
  );
  
  $output .= '<div><strong>'. t('Order total: @total', array('@total' => uc_price($order->order_total, $context))) .'</strong></div>';
  $output .= '<div><strong>'. t('Payment balance: @balance', array('@balance' => uc_price(uc_payment_balance($order), $context))) .'</strong></div>';

  $output .= drupal_get_form('uc_paypoint_terminal_form', $order);
  return $output;
}

/**
 * Administrative payment terminak.
 *
 * It simply adds an amount field and unsets the amount specified in the paypoint data array.
 * Redirect after submission is handled the same way as standard PayPoint payments.
 */
function uc_paypoint_terminal_form($form_state, $order) {
  $form = array();
  $data = uc_paypoint_get_data($order);
  $data['usage_type'] = 'M'; // MOTO (mail order/telephone order), supposed to suppress 3D Pay on admin order.

  $balance = uc_payment_balance($order);

  $context = array(
    'revision' => 'formatted-original',
    'type' => 'amount',
  );

  $options = array(
    'sign' => FALSE,
    'thou' => FALSE,
    'dec' => '.',
  );

  $amount = $balance > 0 ? uc_price($balance, $context, $options) : 0;
  $prefix = variable_get('uc_sign_before_amount', FALSE) ? '' : variable_get('uc_currency_sign', '$');
  $suffix = variable_get('uc_sign_after_amount', FALSE) ? variable_get('uc_currency_sign', '$') : '';

  // Let the administrator set the amount to charge.
  $form['amount_explanation'] = array(
    '#type' => 'markup',
    '#value' => t('Amount to be charged: @amount <br />This amount is fixed and equals to the total order value.', array('@amount' => $prefix . $amount . $suffix)),
    '#prefix' => '<div>',
    '#suffix' => '</div>',
  );

  // External SecPay url.
  $form['#action'] = 'https://www.secpay.com/java-bin/ValCard';

  // Add the items in the array to the form as hidden input fields.
  foreach ($data as $name => $value) {
    $form[$name] = array('#type' => 'hidden', '#value' => $value);
  }
  
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit order'),
  );
  return $form;
}
